# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sk-packet.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fsk-packet.proto\")\n\tscm_entry\x12\x0c\n\x04type\x18\x01 \x02(\r\x12\x0e\n\x06rights\x18\x02 \x03(\r\"J\n\x0fsk_packet_entry\x12\x0e\n\x06id_for\x18\x01 \x02(\r\x12\x0e\n\x06length\x18\x02 \x02(\r\x12\x17\n\x03scm\x18\x04 \x03(\x0b\x32\n.scm_entry')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sk_packet_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SCM_ENTRY']._serialized_start=19
  _globals['_SCM_ENTRY']._serialized_end=60
  _globals['_SK_PACKET_ENTRY']._serialized_start=62
  _globals['_SK_PACKET_ENTRY']._serialized_end=136
# @@protoc_insertion_point(module_scope)
