# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pipe-data.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fpipe-data.proto\"?\n\x0fpipe_data_entry\x12\x0f\n\x07pipe_id\x18\x01 \x02(\r\x12\r\n\x05\x62ytes\x18\x02 \x02(\r\x12\x0c\n\x04size\x18\x03 \x01(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pipe_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PIPE_DATA_ENTRY']._serialized_start=19
  _globals['_PIPE_DATA_ENTRY']._serialized_end=82
# @@protoc_insertion_point(module_scope)
